@@ -63,7 +63,7 @@ class NEAL3Way(object):
     
     
     * Refer to :ref:`FSAHelperFunctions` ``.makeCA`` about the structure of a cell assembly based on the Neuromorphic Embodied Agents that Learn `(NEAL) <http://www.cwa.mdx.ac.uk/NEAL/NEAL.html>`_.
-    * Refer to :ref:`FSAHelperFunctions` ``.getCAConnectors`` for details on how the `neuron populations <http://neuralensemble.org/docs/PyNN/reference/populations.html>`_ within a cell assembly are connected.
+    * Refer to :ref:`FSAHelperFunctions` ``.getCAConnectors`` for details on how the cell units in the `neuron population <http://neuralensemble.org/docs/PyNN/reference/populations.html>`_ within a cell assembly are connected.
     
     Connection (excitatory) between the cell assemblies is based on the "isA" relationship pair.
     
@@ -330,21 +330,23 @@ class NEAL3Way(object):
         for spiketrains from all the cell units of all the cell assemblies for a given data structure (assigned by the ``dataname`` argument)."""
         legpatches = []
         data = getattr(self, dataname) # "basedata" or "propdata" or "reldata"
-        clrs = self.__generate_compatible_subplot_colors(colorname, data.numberUnits)
+        #clrs = self.__generate_compatible_subplot_colors(colorname, data.numberUnits)
+        clrs = cm.get_cmap(colorname, 12) # "Reds", "Greens", "Blues"
         for unit in data.units:
             i = data.getUnitNumber(unit)
-            if self.test_metadata[0]=="all":
-                subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
-                                         color = clrs(1.0 - (i*0.1) ) )
-                legpatches.append( mpatches.Patch(color=clrs( 1.0-(i*0.1) ), label=unit) )
-            else:
-                subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
-                                         color = clrs[i] )
-                legpatches.append( mpatches.Patch(color=clrs[i], label=unit) )
+            #if self.test_metadata[0]=="all":
+            subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
+                                     color = clrs(1.0 - (i*0.1) ) )
+            legpatches.append( mpatches.Patch(color=clrs( 1.0-(i*0.1) ), label=unit) )
+            #else:
+            #    subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
+            #                             color = clrs[i] )
+            #    legpatches.append( mpatches.Patch(color=clrs[i], label=unit) )
         subplotobject.legend( handles=legpatches, shadow=True )
         
     # Private function for returning color map (a tuple) or list of colors
     def __generate_compatible_subplot_colors(self, colorname, numberUnits):
+        """This is no longer used."""
         if self.test_metadata[0]=="all": # returns a tuple
             return cm.get_cmap(colorname, 12) # "Reds", "Greens", "Blues"
         else:
